@@ -22,6 +22,8 @@
 //!   - `simd_allocator`: The wrapper of SIMD-friendly allocator.
 
 pub mod audio;
+/// Rust FFI to `SDL2/SDL.h`
+#[allow(warnings)]
 mod bind;
 mod error;
 pub mod event;
@@ -39,3 +41,8 @@ pub use event::{app, EventBox};
 pub use sdl::*;
 pub use timer::*;
 pub use video::*;
+
+#[cfg(not(target_env = "msvc"))]
+type EnumInt = std::os::raw::c_uint;
+#[cfg(target_env = "msvc")]
+type EnumInt = std::os::raw::c_int;
